@@ -249,7 +249,7 @@ class NavSoapClient():
         return serialized_response
 
 
-    def create_site_location(self, cust_no, name, address, city, state, zip, county, lat, long, field_office_id, cust_resp_grp_id, name2=None, address2=None, lease_id=None, lease_name=None):
+    def create_site_location(self, cust_no, name, address, city, state, zip, county, lat, long, field_office_id, cust_resp_grp_id, site_type, name2=None, address2=None, lease_id=None, lease_name=None):
         """
         Create a Site in NAV.
         """
@@ -276,7 +276,8 @@ class NavSoapClient():
                 siteLat=lat,
                 siteLon=long,
                 locationCode=field_office_id,
-                custRespGroup=cust_resp_grp_id
+                custRespGroup=cust_resp_grp_id,
+                siteType=site_type
         )
 
         serialized_response = serialize_object(soap_response)
